@@ -24,7 +24,7 @@ import time
 import urllib.parse
 import webbrowser
 from datetime import datetime, timezone
-from typing import NoReturn, Optional, cast
+from typing import NoReturn, cast
 
 import id
 import jwt
@@ -312,6 +312,10 @@ class Issuer:
                     raise IdentityError(
                         f"Error response from auth endpoint: {auth_error[0]}"
                     )
+
+                if server.auth_response["state"][0] != server.oauth_session.state:
+                    raise IdentityError("OAuth state mismatch")
+
                 code = server.auth_response["code"][0]
             else:
                 # In the out-of-band case, we wait until the user provides the code
@@ -407,6 +411,6 @@ def detect_credential(client_id: str = _DEFAULT_CLIENT_ID) -> str | None:
     """Calls `id.detect_credential`, but wraps exceptions with our own exception type."""
 
     try:
-        return cast(Optional[str], id.detect_credential(client_id))
+        return cast(str | None, id.detect_credential(client_id))
     except id.IdentityError as exc:
         IdentityError.raise_from_id(exc)
